=========
Reference
=========

Package section
---------------

.. autoclass:: test_cookiecutter.MyClass1
    :members:

.. autoclass:: test_cookiecutter.MyClass2
    :members:

.. autoclass:: test_cookiecutter.MyClass3
    :members:
